// Licensed under the Apache License, Version 2.0 (the "License"); you may not
// use this file except in compliance with the License. You may obtain a copy of
// the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations under
// the License.



module.exports = {

  'Shows how many conflicts have appeared': function (client) {
    const waitTime = client.globals.maxWaitTime;
    const newDatabaseName = client.globals.testDatabaseName;
    const baseUrl = client.options.launch_url;

    client
      .populateDatabaseWithConflicts(newDatabaseName)
      .checkForDocumentCreated('outfit1')
      .loginToGUI()
      .url(baseUrl + '/#/database/' + newDatabaseName + '/_all_docs')

      .clickWhenVisible('.fonticon-table')
      .waitForElementVisible('.table', waitTime, false)

      .waitForElementVisible('.table-container-autocomplete', waitTime, false)
      .waitForElementVisible('.tableview-conflict', waitTime, false)

      .assert.visible('.table [data-conflicts-indicator="true"]')

      .end();
  }
};
